diff lwasm/lwasm.h @ 53:cb4efc47ce9d

Allow macros to shadow/override builtin operations when the "shadow" pragma is active, which is NOT the default
author lost@l-w.ca
date Tue, 05 Apr 2011 21:48:51 -0600
parents bd8b3fbd1e28
children ccaecdff3fc2
line wrap: on
line diff
--- a/lwasm/lwasm.h	Tue Apr 05 21:48:22 2011 -0600
+++ b/lwasm/lwasm.h	Tue Apr 05 21:48:51 2011 -0600
@@ -76,7 +76,8 @@
 	PRAGMA_UNDEFEXTERN = 0x0004,		// undefined symbols are considered to be external
 	PRAGMA_CESCAPES = 0x0008,			// allow C style escapes in fcc, fcs, fcn, etc.
 	PRAGMA_IMPORTUNDEFEXPORT = 0x0010,	// imports symbol if undefined upon export
-	PRAGMA_PCASPCR = 0x0020				// treats ,PC as ,PCR instead of constant offset
+	PRAGMA_PCASPCR = 0x0020,			// treats ,PC as ,PCR instead of constant offset
+	PRAGMA_SHADOW = 0x0040				// allow macros to shadow builtin operations
 };